@@ -4,9 +4,7 @@
 :mod:`Quantulum` class to spoken conversion.
 """
 
-# Quantulum
-from ... import load
-from ... import parser
+from ... import load, parser
 from . import lang
 
 
